@@ -4,6 +4,7 @@ import configparser
 import glob
 import multiprocessing
 import os
+import subprocess
 import sys
 
 import numpy as np
@@ -19,17 +20,20 @@ def generate_blas_flags():
             list: a list of blas flags prefixed with "-l"
     """
     if "CONDA_PREFIX" in os.environ:
+
         if sys.platform == "win32":
             ld_dir = os.path.join(os.getenv("CONDA_PREFIX"), "Library", "bin")
         else:
             ld_dir = os.path.join(os.getenv("CONDA_PREFIX"), "lib")
+
         mkt_rt_bins = glob.glob(os.path.join(ld_dir, "*mkl_rt*"))
         blas_flags = []
         for b in mkt_rt_bins:
-            if b.endswith(".dll"):
-                b = b[:-4]
             if sys.platform != "win32":
                 b = "mkl_rt"
+            else:
+                if b.endswith(".dll"):
+                    b = b[:-4]
             blas_flags = [f"-l{os.path.basename(b)}"]
         return blas_flags
     else:
@@ -38,6 +42,17 @@ def generate_blas_flags():
         )
 
 
+def generate_cxx_flags():
+    """Finds and generates the gcc__cxxflags config option
+
+    Returns:
+        list: a list of cxx flags to pass to .aesararc
+    """
+    sdk_path = subprocess.getoutput("xcrun --show-sdk-path")
+    cxxflag = os.path.join(sdk_path, "usr", "include")
+    return [f"-I{cxxflag}"]
+
+
 def generate_ld_path_flags():
     """Finds and generates the blas__ldflags config option for .aesararc
 
@@ -48,7 +63,10 @@ def generate_ld_path_flags():
             list: a list of ld_path flags prefixed with "-L"
     """
     if "CONDA_PREFIX" in os.environ:
-        ld_dir = os.path.join(os.getenv("CONDA_PREFIX"), "Library", "bin")
+        if sys.platform == "win32":
+            ld_dir = os.path.join(os.getenv("CONDA_PREFIX"), "Library", "bin")
+        else:
+            ld_dir = os.path.join(os.getenv("CONDA_PREFIX"), "lib")
         ld_path_flags = [f"-L{ld_dir}"]
         return ld_path_flags
     else:
@@ -70,26 +88,32 @@ def init_aesararc():
     ldflags = "".join(f"{ld_path} " for ld_path in generate_ld_path_flags())
     ldflags += "".join(f"{blas} " for blas in generate_blas_flags())
     aesararc_config["blas"]["ldflags"] = ldflags
+    if sys.platform == "darwin":
+        aesararc_config.add_section("gcc")
+        aesararc_config["gcc"]["cxxflags"] = "".join(
+            f"{cxxflag} " for cxxflag in generate_cxx_flags()
+        )
     with open(aesararc_config_file, "w") as f:
         aesararc_config.write(f)
 
 
 def _config():
     """Defines the default model hyperparameters and config options"""
+    rng = np.random.default_rng()
     config = {
         "python_version": sys.version,
         "cwd": os.getcwd(),
         "patience": 9000,
         "patience_increase": 2,
         "validation_threshold": 1.003,
-        "seed": 999,
+        "seed": rng.integers(1, 9000),
         "base_lr": 0.0001,
         "max_lr": 0.01,
         "batch_size": 64,
         "max_epoch": 2000,
         "debug": False,
         "notebook": False,
-        "learning_scheduler": "CyclicLR",
+        "learning_scheduler": "ConstantLR",
         "cyclic_lr_mode": "triangular2",
         "cyclic_lr_step_size": 8,
     }
